@@ -1,7 +1,7 @@
 import platform
 import warnings
 
-import semver
+from semver import VersionInfo
 
 from issuewatcher.constants import (
     APPLICATION_NAME,
@@ -15,15 +15,15 @@ def check_python_support():
     Shows warning when Python version is too high.
     :raises OSError: When Python version is too low.
     """
-    current_version = platform.python_version()
-    if semver.compare(current_version, MIN_SUPPORTED_PYTHON_VERSION_INCLUSIVE) < 0:
+    current_version = VersionInfo.parse(platform.python_version())
+    if current_version.compare(MIN_SUPPORTED_PYTHON_VERSION_INCLUSIVE) < 0:
         raise OSError(
             f"Current Python version is '{current_version}' but minimum supported "
             f"Python version by '{APPLICATION_NAME}' is "
             f"{MIN_SUPPORTED_PYTHON_VERSION_INCLUSIVE}."
         )
 
-    if semver.compare(current_version, MAX_SUPPORTED_PYTHON_VERSION_EXCLUSIVE) >= 0:
+    if current_version.compare(MAX_SUPPORTED_PYTHON_VERSION_EXCLUSIVE) >= 0:
         warnings.warn(
             f"Current Python version is '{current_version}' but maximum supported "
             f"Python version by '{APPLICATION_NAME}' is "
